# falco_toolbox

[![PyPI - Version](https://img.shields.io/pypi/v/falco-toolbox.svg)](https://pypi.org/project/falco-toolbox)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/falco-toolbox.svg)](https://pypi.org/project/falco-toolbox)

-----

## Table of Contents

- [falco\_toolbox](#falco_toolbox)
  - [Table of Contents](#table-of-contents)
  - [Installation](#installation)
  - [License](#license)
  - [Acknowledgements](#acknowledgements)

## Installation

```console
pip install falco-toolbox
```

## License

`falco-toolbox` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Acknowledgements

A lot of the code in this package was taken from [django-twc-toolbox](https://github.com/westerveltco/django-twc-toolbox). The license file has been updated to reflect this.